// Copyright 2000-2023 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.jetbrains.python.run

//To generate this maps, need to run the task
//'community/python/build/build-debug-binaries/src/build.gradle#generateImportErrorsMap()'
//After that, copy the contents of the file
// 'community/python/helpers/pydev/build_tools/generate_debugger_import_errors/result.txt' to this map.
//You need to do the same on Windows and Unix
// When you will run it for the second time (second OS),
// please copy previous results from 'community/python/helpers/pydev/build_tools/generate_debugger_import_errors/result.txt' to the same file

val IMPORT_ERRORS_FILTER_MAP = mapOf(
  "ImportError: cannot import name log" to "math.py",
  "AttributeError: 'module' object has no attribute 'cStringIO_CAPI'" to "cStringIO.py",
  "ImportError: cannot import name 'Decimal' from 'decimal'" to "decimal.py",
  "ImportError: cannot import name '_clearcache' from '_struct'" to "_struct.py",
  "ImportError: cannot import name 'recursive_repr'" to "reprlib.py",
  "ImportError: cannot import name 'namedtuple' from 'collections'" to "collections.py",
  "AttributeError: module 'io' has no attribute 'OpenWrapper'" to "io.py",
  "ImportError: cannot import name islice" to "itertools.py",
  "AttributeError: module '_blake2' has no attribute 'blake2b'" to "_blake2.py",
  "ImportError: cannot import name 'iskeyword' from 'keyword'" to "keyword.py",
  "AttributeError: module 'subprocess' has no attribute 'PIPE'" to "subprocess.py",
  "NameError: name 'MIN_REPEAT' is not defined" to "sre_constants.py",
  "ImportError: cannot import name 'format_exception_only' from 'traceback'" to "traceback.py",
  "ImportError: cannot import name 'encodestring'" to "quopri.py",
  "ModuleNotFoundError: No module named 'msvcrt'" to "select.py",
  "ModuleNotFoundError: No module named 'urllib.parse'; 'urllib' is not a package" to "urllib.py",
  "ImportError: cannot import name 'ascii_letters' from 'string'" to "string.py",
  "ImportError: cannot import name 'eq' from 'operator'" to "operator.py",
  "AttributeError: module 'weakref' has no attribute 'ref'" to "weakref.py",
  "AttributeError: module 'warnings' has no attribute 'warn'" to "warnings.py",
  "AttributeError: 'module' object has no attribute 'split'" to "string.py",
  "ImportError: cannot import name iskeyword" to "keyword.py",
  "AttributeError: module 'functools' has no attribute 'lru_cache'" to "functools.py",
  "ImportError: cannot import name 'GenericAlias' from 'types'" to "types.py",
  "AttributeError: module '_asyncio' has no attribute 'Future'" to "_asyncio.py",
  "ImportError: cannot import name 'heappush' from 'heapq'" to "heapq.py",
  "AttributeError: module 'json' has no attribute 'loads'" to "json.py",
  "ImportError: cannot import name wraps" to "functools.py",
  "ImportError: cannot import name 'deque' from 'collections'" to "collections.py",
  "ImportError: cannot import name 'sha512'" to "hashlib.py",
  "ImportError: cannot import name 'calcsize'" to "struct.py",
  "AttributeError: module 'sysconfig' has no attribute 'get_path'" to "sysconfig.py",
  "ImportError: cannot import name 'CommandCompiler'" to "codeop.py",
  "ImportError: cannot import name 'reduce'" to "functools.py",
  "AttributeError: 'module' object has no attribute 'path'" to "os.py",
  "ImportError: cannot import name 'nested_scopes'" to "__future__.py",
  "ImportError: cannot import name curdir" to "posixpath.py",
  "AttributeError: module 'threading' has no attribute '_shutdown'" to "threading.py",
  "AttributeError: 'module' object has no attribute 'current_thread'" to "threading.py",
  "ImportError: cannot import name 'b2a_base64' from 'binascii'" to "binascii.py",
  "NameError: name 'socket' is not defined" to "_socket.py",
  "AttributeError: 'module' object has no attribute 'Random'" to "_random.py",
  "AttributeError: module 'socket' has no attribute '_GLOBAL_DEFAULT_TIMEOUT'" to "socket.py",
  "ModuleNotFoundError: No module named 'collections.abc'; 'collections' is not a package" to "collections.py",
  "ImportError: cannot import name 'get_origin' from 'typing'" to "typing.py",
  "ImportError: cannot import name 'MutableMapping'" to "_collections_abc.py",
  "AttributeError: 'module' object has no attribute 'Z_SYNC_FLUSH'" to "zlib.py",
  "ImportError: cannot import name 'WeakKeyDictionary'" to "weakref.py",
  "ImportError: cannot import name partial" to "_functools.py",
  "AttributeError: module 'ssl' has no attribute 'SSLWantReadError'" to "ssl.py",
  "AttributeError: 'module' object has no attribute 'python_implementation'" to "platform.py",
  "AttributeError: module 'platform' has no attribute 'python_implementation'" to "platform.py",
  "ImportError: cannot import name 'Context' from '_contextvars'" to "_contextvars.py",
  "ImportError: cannot import name 'log'" to "math.py",
  "AttributeError: module '_compression' has no attribute 'BaseStream'" to "_compression.py",
  "ImportError: cannot import name hexlify" to "binascii.py",
  "AttributeError: 'module' object has no attribute 'heappush'" to "heapq.py",
  "ImportError: cannot import name 'heappush'" to "heapq.py",
  "NameError: name '_check_date_fields' is not defined" to "_datetime.py",
  "AttributeError: module 'os' has no attribute 'path'" to "os.py",
  "ImportError: cannot import name calcsize" to "struct.py",
  "ImportError: cannot import name '_clearcache'" to "_struct.py",
  "AttributeError: 'module' object has no attribute 'Queue'" to "Queue.py",
  "ImportError: cannot import name 'contextmanager'" to "contextlib.py",
  "AttributeError: module 'typing' has no attribute 'Iterable'" to "typing.py",
  "AttributeError: module 're' has no attribute 'search'" to "re.py",
  "AttributeError: module 'mimetypes' has no attribute 'inited'" to "mimetypes.py",
  "AttributeError: 'module' object has no attribute 'search'" to "re.py",
  "ImportError: cannot import name 'nested_scopes' from '__future__'" to "__future__.py",
  "ImportError: cannot import name DEFAULT_BUFFER_SIZE" to "_io.py",
  "ImportError: cannot import name 'warn' from 'warnings'" to "warnings.py",
  "AttributeError: module '_hashlib' has no attribute 'openssl_sha3_224'" to "_sha3.py",
  "AttributeError: 'module' object has no attribute '_GLOBAL_DEFAULT_TIMEOUT'" to "socket.py",
  "AttributeError: module '_osx_support' has no attribute 'customize_config_vars'" to "_osx_support.py",
  "ImportError: cannot import name compile_command" to "code.py",
  "ImportError: cannot import name '_check_methods' from '_collections_abc'" to "_collections_abc.py",
  "ImportError: cannot import name 'get_config_var'" to "sysconfig.py",
  "AttributeError: module '_sha3' has no attribute 'sha3_224'" to "_sha3.py",
  "ImportError: cannot import name itemgetter" to "operator.py",
  "AttributeError: module 'types' has no attribute 'MethodType'" to "types.py",
  "ModuleNotFoundError: No module named 'asyncio.events'; 'asyncio' is not a package" to "asyncio.py",
  "ImportError: cannot import name 'format_exc' from 'traceback'" to "traceback.py",
  "ImportError: cannot import name 'calcsize' from 'struct'" to "struct.py",
  "AttributeError: module 'getpass' has no attribute 'default_getpass'" to "getpass.py",
  "ImportError: cannot import name 'Union'" to "_ctypes.py",
  "ImportError: cannot import name Union" to "_ctypes.py",
  "ImportError: cannot import name get_config_var" to "sysconfig.py",
  "AttributeError: 'module' object has no attribute 'IterableUserDict'" to "UserDict.py",
  "ImportError: cannot import name nested_scopes" to "__future__.py",
  "NameError: name 'model' is not defined" to "pyexpat.py",
  "AttributeError: 'module' object has no attribute 'openssl_md_meth_names'" to "_hashlib.py",
  "ImportError: cannot import name 'signature' from 'inspect'" to "inspect.py",
  "ImportError: cannot import name 'contextmanager' from 'contextlib'" to "contextlib.py",
  "AttributeError: 'module' object has no attribute 'ClassType'" to "types.py",
  "AttributeError: module '_compat_pickle' has no attribute 'NAME_MAPPING'" to "_compat_pickle.py",
  "AttributeError: module 'pickle' has no attribute 'Pickler'" to "pickle.py",
  "ImportError: cannot import name Random" to "random.py",
  "ImportError: cannot import name 'MappingProxyType' from 'types'" to "types.py",
  "ImportError: cannot import name HAVE_ARGUMENT" to "opcode.py",
  "ImportError: cannot import name 'format_exc'" to "traceback.py",
  "AttributeError: module 'zlib' has no attribute 'Z_SYNC_FLUSH'" to "zlib.py",
  "AttributeError: module 'pydoc' has no attribute 'HTMLDoc'" to "pydoc.py",
  "ImportError: cannot import name deque" to "_collections.py",
  "AttributeError: module '_bootlocale' has no attribute 'getpreferredencoding'" to "_bootlocale.py",
  "AttributeError: module '_sitebuiltins' has no attribute 'Quitter'" to "_sitebuiltins.py",
  "AttributeError: module 'queue' has no attribute 'Queue'" to "queue.py",
  "AttributeError: module 'sre_compile' has no attribute 'SRE_FLAG_ASCII'" to "sre_compile.py",
  "ImportError: cannot import name '_args_from_interpreter_flags'" to "subprocess.py",
  "ImportError: cannot import name 'Protocol' from 'typing'" to "typing.py",
  "ImportError: cannot import name _unicode" to "genericpath.py",
  "AttributeError: 'module' object has no attribute 'MutableMapping'" to "_abcoll.py",
  "AttributeError: 'module' object has no attribute 'CAPI'" to "_socket.py",
  "ImportError: cannot import name 'curdir' from 'posixpath'" to "posixpath.py",
  "ImportError: cannot import name warn" to "warnings.py",
  "ImportError: cannot import name 'ascii_letters'" to "string.py",
  "ImportError: cannot import name WeakSet" to "_weakrefset.py",
  "AttributeError: 'module' object has no attribute 'BaseHTTPRequestHandler'" to "BaseHTTPServer.py",
  "AttributeError: 'module' object has no attribute 'customize_config_vars'" to "_osx_support.py",
  "AttributeError: 'module' object has no attribute 'loads'" to "json.py",
  "ImportError: cannot import name 'WeakSet'" to "_weakrefset.py",
  "ModuleNotFoundError: No module named 'xml.parsers'; 'xml' is not a package" to "xml.py",
  "ImportError: cannot import name CommandCompiler" to "codeop.py",
  "AttributeError: module 'sre_parse' has no attribute 'TYPE_FLAGS'" to "sre_parse.py",
  "ImportError: cannot import name 'namedtuple'" to "collections.py",
  "AttributeError: module 'genericpath' has no attribute '_splitext'" to "genericpath.py",
  "ImportError: cannot import name 'getfullargspec'" to "inspect.py",
  "ModuleNotFoundError: No module named 'importlib.machinery'; 'importlib' is not a package" to "importlib.py",
  "ImportError: cannot import name 'InteractiveConsole' from 'code'" to "code.py",
  "ImportError: cannot import name _get_proxy_settings" to "_scproxy.py",
  "ImportError: cannot import name 'WeakSet' from '_weakrefset'" to "_weakrefset.py",
  "AttributeError: module 'selectors' has no attribute 'SelectSelector'" to "selectors.py",
  "ImportError: cannot import name 'datetime' from 'datetime'" to "datetime.py",
  "ImportError: cannot import name 'HAVE_ARGUMENT'" to "opcode.py",
  "AttributeError: 'module' object has no attribute 'parse'" to "sre_parse.py",
  "AttributeError: module '_hashlib' has no attribute 'openssl_md_meth_names'" to "_hashlib.py",
  "AttributeError: 'module' object has no attribute 'Message'" to "mimetools.py",
  "ModuleNotFoundError: No module named 'importlib._bootstrap'; 'importlib' is not a package" to "importlib.py",
  "ImportError: cannot import name ABCMeta" to "abc.py",
  "AttributeError: module 'ast' has no attribute 'NodeVisitor'" to "ast.py",
  "ImportError: cannot import name 'RLock'" to "threading.py",
  "AttributeError: module 'socketserver' has no attribute 'TCPServer'" to "socketserver.py",
  "ImportError: cannot import name array" to "array.py",
  "ImportError: cannot import name 'Full'" to "queue.py",
  "ImportError: cannot import name 'itemgetter' from 'operator'" to "operator.py",
  "ImportError: cannot import name 'recursive_repr' from 'reprlib'" to "reprlib.py",
  "ImportError: cannot import name 'CommandCompiler' from 'codeop'" to "codeop.py",
  "AttributeError: 'module' object has no attribute 'default_getpass'" to "getpass.py",
  "ImportError: cannot import name 'b64encode' from 'base64'" to "base64.py",
  "ImportError: cannot import name 'wraps' from 'functools'" to "functools.py",
  "AttributeError: 'module' object has no attribute 'datetime'" to "datetime.py",
  "ImportError: cannot import name contextmanager" to "contextlib.py",
  "AttributeError: module 'gzip' has no attribute 'GzipFile'" to "gzip.py",
  "ImportError: cannot import name 'b2a_base64'" to "binascii.py",
  "AttributeError: module '_socket' has no attribute 'socket'" to "_socket.py",
  "ImportError: cannot import name urlsplit" to "urlparse.py",
  "AttributeError: module 'tokenize' has no attribute 'open'" to "tokenize.py",
  "ModuleNotFoundError: No module named 'xmlrpc.client'; 'xmlrpc' is not a package" to "xmlrpc.py",
  "ImportError: cannot import name namedtuple" to "collections.py",
  "ImportError: cannot import name 'Empty' from '_queue'" to "_queue.py",
  "AttributeError: module 'numbers' has no attribute 'Number'" to "numbers.py",
  "AttributeError: module 'select' has no attribute 'select'" to "select.py",
  "ImportError: cannot import name 'EXACT_TOKEN_TYPES' from 'token'" to "token.py",
  "ImportError: cannot import name 'encodestring' from 'quopri'" to "quopri.py",
  "ModuleNotFoundError: No module named 'http.client'; 'http' is not a package" to "http.py",
  "AttributeError: module '_random' has no attribute 'Random'" to "_random.py",
  "AttributeError: module 'threading' has no attribute 'current_thread'" to "threading.py",
  "AttributeError: module 're' has no attribute 'compile'" to "re.py",
  "AttributeError: module 'stat' has no attribute 'S_ISLNK'" to "stat.py",
  "ImportError: cannot import name 'suppress' from 'contextlib'" to "contextlib.py",
  "ImportError: cannot import name 'MethodType' from 'types'" to "types.py",
  "ImportError: cannot import name 'datetime'" to "datetime.py",
  "AttributeError: 'module' object has no attribute 'SRE_FLAG_IGNORECASE'" to "sre_compile.py",
  "AttributeError: 'module' object has no attribute 'pickle'" to "copy_reg.py",
  "AttributeError: module 'enum' has no attribute 'IntFlag'" to "enum.py",
  "ImportError: cannot import name Fault" to "xmlrpclib.py",
  "AttributeError: module 'dis' has no attribute 'COMPILER_FLAG_NAMES'" to "dis.py",
  "ImportError: cannot import name SSLError" to "_ssl.py",
  "ImportError: cannot import name build_time_vars" to "_sysconfigdata.py",
  "AttributeError: 'module' object has no attribute 'ref'" to "weakref.py",
  "ImportError: cannot import name getargspec" to "inspect.py",
  "AttributeError: module 'stat' has no attribute 'S_ISDIR'" to "stat.py",
  "AttributeError: module 'logging' has no attribute 'getLogger'" to "logging.py",
  "ModuleNotFoundError: No module named 'email.parser'; 'email' is not a package" to "email.py",
  "AttributeError: module 'abc' has no attribute 'ABCMeta'" to "abc.py",
  "ImportError: cannot import name 'Union' from '_ctypes'" to "_ctypes.py",
  "ImportError: cannot import name 'Decimal'" to "decimal.py",
  "ImportError: No module named parse" to "urllib.py",
  "ModuleNotFoundError: No module named 'concurrent.futures'; 'concurrent' is not a package" to "concurrent.py",
  "ImportError: cannot import name 'reduce' from 'functools'" to "functools.py",
  "AttributeError: 'module' object has no attribute 'opname'" to "dis.py",
  "AttributeError: module 'codecs' has no attribute 'register'" to "codecs.py",
  "ImportError: cannot import name 'sha512' from 'hashlib'" to "hashlib.py",
  "NameError: name 'N_TOKENS' is not defined" to "token.py",
  "ImportError: cannot import name time" to "time.py",
  "ImportError: cannot import name 'bisect' from 'bisect'" to "bisect.py",
  "AttributeError: module '_sysconfigdata__darwin_darwin' has no attribute 'build_time_vars'" to "_sysconfigdata__darwin_darwin.py",
  "ImportError: cannot import name 'itemgetter'" to "operator.py",
  "ImportError: cannot import name _clearcache" to "_struct.py",
  "AttributeError: 'module' object has no attribute 'S_ISLNK'" to "stat.py",
  "ImportError: cannot import name 'iskeyword'" to "keyword.py",
  "AttributeError: module 'sre_parse' has no attribute 'parse'" to "sre_parse.py",
  "ImportError: cannot import name 'gettext'" to "gettext.py",
  "AttributeError: module 'io' has no attribute 'open'" to "io.py",
  "ImportError: cannot import name 'Random'" to "random.py",
  "ImportError: cannot import name 'InteractiveConsole'" to "code.py",
  "ImportError: cannot import name 'fork_exec' from '_posixsubprocess'" to "_posixsubprocess.py",
  "AttributeError: 'module' object has no attribute 'GzipFile'" to "gzip.py",
  "ImportError: cannot import name 'SimpleQueue'" to "multiprocessing.py",
  "ImportError: cannot import name 'MappingProxyType'" to "types.py",
  "AttributeError: module 'enum' has no attribute 'global_enum'" to "enum.py",
  "ImportError: cannot import name 'HAVE_ARGUMENT' from 'opcode'" to "opcode.py",
  "ImportError: cannot import name format_exc" to "traceback.py",
  "AttributeError: module '_sysconfigdata_m_darwin_darwin' has no attribute 'build_time_vars'" to "_sysconfigdata_m_darwin_darwin.py",
  "AttributeError: module 'token' has no attribute '__all__'" to "token.py",
  "ImportError: cannot import name 'b64encode'" to "base64.py",
  "ImportError: cannot import name 'curdir'" to "posixpath.py",
  "AttributeError: 'module' object has no attribute 'TCPServer'" to "SocketServer.py",
  "ImportError: cannot import name 'log' from 'math'" to "math.py",
  "NameError: name 'LITERAL' is not defined" to "sre_constants.py",
  "AttributeError: module 'copyreg' has no attribute 'pickle'" to "copyreg.py",
  "AttributeError: 'module' object has no attribute 'BufferedIOBase'" to "io.py")